function l = calibrate(image, curve)

%CALIBRATE calibrate(image, curve)
%   
%   The calibrate function calibrates the image, parameter 'image'
%   using the camera curve, parameter 'curve'.
%	'curve' is the 3-by-256 element vector containing the response curve of the
%	camera used. Can be obtained through the mkhdr program created by
%	Debevec, Hawkins & Duiker (California 1999).
%
%
%   AUTHORS:
%   Jansson Sara        sarja751
%   Linnersund Karin    karli734
%
%   
%   REFERENCES
%   - Recovering high dynamic range images from Photographs (Paul E. Debevec et. al.)
%   - High Dynamic Range Images, TNM078 - Image Based Rendering (Jonas Unger, 2004)
%

Ered = zeros(size(image(:,:,1)));
Egreen = zeros(size(image(:,:,1)));
Eblue = zeros(size(image(:,:,1)));
imagenew = zeros(size(image));

 logcurve = 2.^curve;

 for i=1:1:size(image,1)
     for j=1:1:size(image,2)
         
        red = image(i,j,1);
        green = image(i,j,2);
        blue = image(i,j,3);
        
        Ered(i,j) = logcurve(red+1,1);
        Egreen(i,j) = logcurve(green+1,2);
        Eblue(i,j) = logcurve(blue+1,3);

        imagenew(i,j,1) = Ered(i,j);
        imagenew(i,j,2) = Egreen(i,j);
        imagenew(i,j,3) = Eblue(i,j);
     end
 end

%   The return value from the routine is the calibrated image  
l = imagenew;