function hdr = makehdr(infile, min_exp, curve, rows, columns);

%MAKEHDR makehdr(infile, min_exp, curve)
%   
%MAKEHDR Creates a High-Dynamic Range Radiance Map
% from a set of low dynamic range images.
%	
% 'infile' is a textfile containing the names of the 
% low dynamic range images to use. The image names 
% in the file should be ordered in ascending order
% with respect to the exposure times.
%
% 'min_exp' is the shortest exposure time used in the
% image sequence. 'min_exp' should correspond to the 
% exposure time of the first image in the sequence.
% The exposures can be assumed being 1 f-stop apart,
% i.e. the exposure time is doubled between adjacent
% images in the sequence. 
% delta t(j+1) = 2 * delta t(j)
% the shortest exposure time is 1/4000 seconds
%
% 'curve' is the 3-by-256 element vector containing 
% the response curve of the camera used. 
% Can be obtained through the mkhdr or HDRShope 
% program created by Debevec, Hawkins & Duiker
% (California 1999).
%
% The return value hdr from the routine is the 
% High Dynamic Range Radiance Map created from
% the image sequence.
%
%
%   AUTHORS:
%   Jansson Sara        sarja751
%   Linnersund Karin    karli734
%
%   
%   REFERENCES
%   - Recovering high dynamic range images from Photographs (Paul E. Debevec et. al.)
%   - High Dynamic Range Images, TNM078 - Image Based Rendering (Jonas Unger, 2004)
%

 file = fopen(infile, 'r');
frewind(file);

image = zeros(rows,columns,3);
hdr = zeros(size(image));
hdrnom = zeros(size(image));
hdrdenom = zeros(size(image));
g = weightfunction;% modified by me jlj 2007

gred = zeros(size(image(:,:,1)));
ggreen = zeros(size(image(:,:,1)));
gblue = zeros(size(image(:,:,1)));
weighted = zeros(size(image));

while 1
    %loopa igenom vr textfil
    filename = fgetl(file);
    if ~ischar(filename)
        break;
    end
    
    image = imread(filename);
    image=double(image); % modified by me jlj 2007
    for i=1:1:size(image,1)
        for j=1:1:size(image,2)
            
            red = image(i,j,1);
            green = image(i,j,2);
            blue = image(i,j,3);
        
            gred(i,j) = g(red+1);
            ggreen(i,j) = g(green+1);
            gblue(i,j) = g(blue+1);

            weighted(i,j,1) = gred(i,j);
            weighted(i,j,2) = ggreen(i,j);
            weighted(i,j,3) = gblue(i,j);
            
        end
    end
            
            
    calImage = calibrate(image,curve);
    weightImage = (weighted.*calImage)/(min_exp);
  
    
    hdrnom = hdrnom + weightImage;
    hdrdenom = hdrdenom + weighted;
    
    min_exp = min_exp*2;
    
end

hdr = hdrnom./hdrdenom;




