function image = remap2pixels(hdr, exp, curve)

%REMAP2PIXELS remap2pixels(hdr, exp, curve)
%   
%   This function takes a virtual photograph of the radiance map at a given
%   exposure. 
%
% 
%   AUTHORS:
%   Jansson Sara        sarja751
%   Linnersund Karin    karli734
%   Unger Jonas has helped a lot with this function!
%
%   
%   REFERENCES
%   - Recovering high dynamic range images from Photographs (Paul E. Debevec et. al.)
%   - High Dynamic Range Images, TNM078 - Image Based Rendering (Jonas Unger, 2004)
%

%Create the virtual photograph, same size as hdr
image = zeros(size(hdr));
[height width channels] = size(hdr);
%div = max(hdr(:));
%Create a huge array with three columns
val = zeros(59766,3);
%for each channel remap the values from the cameracurve to lie between 1
%and 256
for k = 1:1:3
    channel = 2.^curve(:,k);
    val(:,k) = interp1(channel, 1 : 256/60000 : 256);
    %map the radiancevalue or if to high (saturated) 59765
    radval = min(59765, round(59766 * ((hdr(:,:,k)*exp))));
    image(:,:,k) = reshape(val(radval+1, k), [height width]);   
end;